
#ifndef READ_USER_PASS_FROM_FILE_H_
#define READ_USER_PASS_FROM_FILE_H_


int *get_user_passwd();

#endif /* READ_USER_PASS_FROM_FILE_H_ */



